# DelphaDBManagement

Management API for Delpha to work around Data inside the Cassandra Cluster

This repository is python based yet, to be open to other languages (Java, JavaScript, ...)
Module to handle DB Managmenet on our Cassandra Cluster.


![title](docs/images/db1.png)

# Security Objectives

Need a really secure way to handle data : 

**Private Keys** will be generated by Delpha only and will be stored inside an authentication table inside Cassandra. Users will need to match a given private key to access the DBMS. This key will be bound to the dedicated organisation, and only one Private Key will be tagged as Admin and unlock all the DBMS access.

![title](docs/images/db3.png)

![title](docs/images/db2.png)



# Installation
### Requirements
**Python** : >3.8

### Install Dependencies

Common

```bash
pip install -r requirements.txt
```

### Salesforce Manager

Parameter : instance_name: Salesforce Instance name
Parameter : lient_id: Consumer ID for authorized app
Parameter : client_secret: Consumer Secret for authorized app
Parameter : username: usernam to login to Instance of Salesforce
Parameter : param password: password to login to Instance of Salesforce
Parameter : param security_token: User's security token





### Cassandra Manager



### How to - Pip

```shell
python setup.py sdist bdist_wheel
twine upload dist/*
```




## License
